/**
 * 审批模块(合同)
 */
import {httpGet,httpPost} from "@/utils/request.js"

/**
 * 合同审批列表
 * @param {string} ContractType 合同类型，枚举值：’新签合同’,’续约合同’,’补充协议’
 * @param {string} Status 合同状态，枚举值：’待审批’,’已审批’,’已驳回’,’已撤回’
 * @param {int} ProductId 客户类型：传0或者不传为当前账号权限,1 代表是：ficc；2 代表是：权益
 * @param {string} SellerId 选择的销售id
 * @param {string} Keyword 搜索关键字
 * @param {string} ModifyStartTime 服务更新时间的选择开始时间，格式：2021-05-23 00:00:00
 * @param {string} ModifyEndTime 服务更新时间的选择结束时间，格式：2021-05-26 23:59:59
 */
export const apiContractApproveList=params=>{
	return httpGet('/contract_approval/list',{...params,PageSize:20})
}

/**
 * 合同审批详情 (在审批状态为 待审批、处理中 时 使用审批单详情 其余均使用合同详情)
 * @param {int} ContractApprovalId 审批单id
 * @param {int} ContractApprovalRecordId 审批流程单id  (从消息列表进入传此参数)
 */
export const apiContractApprovalDetail=params=>{
	return httpGet('/contract_approval/detail',params)
}

/**
 * 合同详情
 * @param {int} ContractId 合同id 
 */
export const apiContractDetail=params=>{
	return httpGet('/contract/detail',params) 
}

/**
 * 合同审批 通过
 * @param {int} ContractId 合同id
 */
export const apiContractApproved=params=>{
	return httpPost('/contract_approval/approved',params)
}

/**
 * 合同审批 拒绝
 * @param {int} ContractId 审批单id
 * @param {string} Remark 理由  
 */
export const apiContractReject=params=>{
	return httpPost('/contract_approval/reject',params)
}

/**
 * 合同搜索
 * @param {string} CompanyName 搜索关键字
 */
export const apiContractSearch=params=>{
	return httpGet('/contract/company_list',params)
}

/**
 * 合同列表
 * @param {int} CurrentIndex 页码 
 * @param {string} Keyword 
 */
export const apiContractList=params=>{
	return httpGet('/contract/list',params)
}

/**
 * 合同回签附件
 * @param {int}  ContractId 合同id
 * @param {string}  FileUrl  文件地址 多个用#隔开
 */
export const apiContractSignBackFiles=params=>{
	return httpPost('/contract/upload_check_back_file',params)
}