/**
 * 审批模块(用印)
 */
import {httpGet,httpPost} from "@/utils/request.js"

/**
 * 获取审批流详情(目前crm1.0 只在发起用印申请时需要调用此接口)
 * @param {int} FlowId 审批流程id；1：ficc客户审批；2：权益客户审批；3：ficc合同审批，4：权益合同审批，5：用印审批
 * 
 */
export const apiFlowDetail=params=>{
	return httpGet('/approval/flowDetail',params)
}

/**
 * 新增用印
 * @param {string} CompanyName 客户名称，甲方名称
 * @param {int}  ContractId	系统合同id
 * @param {int}  CreditCode	社会统一信用代码
 * @param {string}  FileUrl	文件附件地址
 * @param {int}		FileNum	文件份数
 * @param {string}  Remark 备注
 * @param {string} SealType 加盖印章类型，枚举值：'合同章', '公章', '法人章'
 * @param {string}  ServiceType	业务类型，枚举值：'新增业务', '续约业务', '补充协议'
 * @param {string}  Use	用印用途，枚举值：'销售合同', '渠道合同', '付款通知函', '招投标', '战略合作协议'
 * @param {string} UseCompanyName 实际使用方客户名称  
 */
export const apiSealAdd=params=>{
	return httpPost('/seal/add',params)
}

/**
 * 用印列表搜索
 */
export const apiSealSearch=params=>{
	return httpGet('/seal/company_list',params)
}

/**
 * 用印客户搜索出对应客户名称
 * @param {string} CompanyName 客户名称 
 */
export const apiSearchCustome=params=>{
	return httpGet('/contract/company_list',{...params,Status:'已审批'})
}

/**
 * 根据客户搜索出对应客户下面合同数据
 * @param {string} 	Status 合同状态(固定 已审批)
 * @param {string}  Keyword	搜索关键字(对应客户名称)
 */
export const apiSearchContract=params=>{
	return httpGet('/contract/list',{...params,Status:'已审批'})
}

/**
 * 审批单列表
 * @param {type} Status	状态：待审批、处理中、已审批、已作废 
 */
export const apiSealList=params=>{
	return httpGet('/seal_approval/list',params)
}

/**
 * 审批单详情
 * @param {int}  ContractApprovalId 审批单id
 * @param {int}  ContractApprovalRecordId 审批流程单id
 */
export const apiSealDetail=params=>{
	return httpGet('/seal_approval/detail',params)
}

/**
 * 用印审批通过
 * @param {int} SealId
 */
export const apiApprovalPass=params=>{
	return httpPost('/seal_approval/approved',params)
}

/**
 * 修改用印审批单并通过审批
 */
export const apiApprovalPassModify=params=>{
	return httpPost('/seal/check_edit',params)
}

/**
 * 用印审批驳回
 * @param {int} SealId
 * @param {string} Remark  
 */
export const apiApprovalReject=params=>{
	return httpPost('/seal_approval/reject',params)
}

/**
 * 用印作废
 * @param {boolean} IsInvalidContract 是否同步作废合同
 * @param {int} SealId 用印id
 */
export const apiInvalidSeal=params=>{
	return httpPost('/seal/invalid',params)
}

/**
 * 用印编辑
 */
export const apiSealEdit=params=>{
	return httpPost('/seal/edit',params)
}

/**
 * 用印撤回
 */
export const apiSealCancelApply=params=>{
	return httpGet('/seal_approval/cancelApply',params)
}